@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.164-4-g0ee379e
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.165-3-gda1e527
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.165';
+our $VERSION = '0.166';
 
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -382,7 +382,7 @@ sub configure {
         'Test::ChangesHasContent',
         [ 'Test::MinimumVersion' => { ':version' => '2.000010', max_target_perl => '5.006' } ],
         [ 'PodSyntaxTests'      => { ':version' => '5.040' } ],
-        [ 'PodCoverageTests'    => { ':version' => '5.040' } ],
+        'Test::Pod::Coverage::TrustMe',
         [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'], directories => [qw(examples lib script t xt)] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
         ($ENV{CONTINUOUS_INTEGRATION} ? () : [ 'Test::Pod::No404s' => { ':version' => '1.003' } ] ),
@@ -390,8 +390,7 @@ sub configure {
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1,
             version_extractor => ( ( any { $_ ne 'MakeMaker' } $self->installer ) ? 'Module::Metadata' : 'ExtUtils::MakeMaker' ),
-            include => [ sort qw(autodie Encode File::Temp JSON::PP Module::Runtime Sub::Name YAML),
-                    $self->_plugin_removed('PodCoverageTests') ? () : 'Pod::Coverage' ] } ],
+            include => [ sort qw(autodie Encode File::Temp JSON::PP Module::Runtime Sub::Name YAML) ] } ],
         [ 'Test::Portability'   => { ':version' => '2.000007' } ],
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
@@ -669,7 +668,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.165
+version 0.166
 
 =head1 SYNOPSIS
 
@@ -770,7 +769,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     max_target_perl = 5.006
     [PodSyntaxTests]
     :version = 5.040
-    [PodCoverageTests]
+    [Test::Pod::Coverage::TrustMe]
     :version = 5.040
     [Test::PodSpelling]
     :version = 2.006003
@@ -1053,7 +1052,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [VerifyPhases / PHASE VERIFICATION]
     :version = 0.015
 
-=for Pod::Coverage configure mvp_multivalue_args
+=for Pod::Coverage commit_files_after_release configure pause_cfg_dir pause_cfg_file
 
 =for stopwords metacpan
 
@@ -1075,7 +1074,7 @@ otherwise the version is incremented after each release, in the F<*.pm> files.
 
 Subroutines can be considered "covered" for pod coverage tests by adding a
 directive to pod (as many as you'd like),
-as described in L<Pod::Coverage::TrustPod>:
+as described in L<Pod::Coverage::TrustMe>:
 
     =for Pod::Coverage foo bar baz
 
